==> bootstrap-react-2.1.0.tgz: package/lib/page-proxy.js <==
import "core-js/modules/es6.promise";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.regexp.match";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import React, { Component } from 'react';
import Layout from '_/src/layout';
var currentPage = '$$currentPage';
var df = 'default';

var PageProxy =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(PageProxy, _Component);

  function PageProxy() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      hasError: false
    };
    return _this;
  }

  var _proto = PageProxy.prototype;

  _proto.getPagePath = function getPagePath(props) {
    var _ref = props || this.props,
        url = _ref.match.url;

    return url.substr(1) || 'home';
  };

  _proto.componentDidMount = function componentDidMount() {
    this.loadAsyncPages(this.getPagePath(this.props));
  };

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var currentPath = this.getPagePath(this.props);
    var nextPath = this.getPagePath(nextProps);

    if (currentPath !== nextPath) {
      this.loadAsyncPages(nextPath);
    }
  };

  PageProxy.getDerivedStateFromError = function getDerivedStateFromError(error) {
    return {
      hasError: true
    };
  };

  _proto.componentDidCatch = function componentDidCatch(err, info) {
    this.warn('哎呀，出错了');
    this.warn(info.componentStack);
  };

  _proto.renderPageElement = function renderPageElement() {
    var state = this.state;
    var pagePath = this.getPagePath(this.props);
    var PageComponent = state[pagePath];

    if (PageComponent) {
      var useLayout = PageComponent.useLayout;
      this.useLayout = typeof useLayout === 'boolean' ? useLayout : true; //缓存当前useLayout的状态，进入下一个页面的时候避免发生layout的切换导致的闪动

      return [React.createElement(PageComponent, this.props), this.useLayout];
    }

    var LoadingComp = this.props.LoadingComp; //读取之前的layout状态，如果不存在就用true

    this.useLayout = typeof this.useLayout === 'boolean' ? this.useLayout : true;

    if (LoadingComp) {
      return [React.createElement(LoadingComp, null), this.useLayout];
    }

    return [React.createElement("div", null, "\u52A0\u8F7D\u4E2D..."), this.useLayout];
  };

  _proto.render = function render() {
    var ErrorComp = this.props.ErrorComp;
    if (this.state.hasError && ErrorComp) return React.createElement(ErrorComp, null);

    var _this$renderPageEleme = this.renderPageElement(),
        pageElement = _this$renderPageEleme[0],
        useLayout = _this$renderPageEleme[1];

    if (!useLayout) return pageElement;
    return React.createElement(Layout, this.props, pageElement);
  };

  _proto.warn = function warn(msg, err) {
    if (console && console.error) {
      console.error(msg);
      if (err) throw err;
    }
  };

  _proto.loadAsyncPages = function loadAsyncPages(path) {
    var _this2 = this;

    var loadPage = this.state[path] ? undefined : import(
    /* webpackMode: "lazy", webpackChunkName: "[request]" */
    "_/src/pages/" + path + "/page-view");
    Promise.all([loadPage]).then(function (_ref2) {
      var PageComponent = _ref2[0];
      var needUpdate = false;
      var updateData = {};

      if (PageComponent) {
        needUpdate = true;
        updateData[path] = PageComponent[df];
      }

      if (_this2.state[currentPage] !== path) {
        needUpdate = true;
        updateData[currentPage] = path;
      }

      if (needUpdate) {
        _this2.setState(updateData);
      }
    }).catch(function (err) {
      _this2.warn("\u9875\u9762 " + path + " \u52A0\u8F7D\u5931\u8D25", err);
    });
  };

  return PageProxy;
}(Component);

export { PageProxy as default };

==> bootstrap-react-2.1.2.tgz: package/lib/page-proxy.js <==
import "core-js/modules/es6.promise";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.string.iterator";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import "core-js/modules/es6.regexp.match";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import React, { Component } from 'react';
var currentPage = '$$currentPage';
var df = 'default';

var PageProxy =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(PageProxy, _Component);

  function PageProxy() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      hasError: false
    };
    return _this;
  }

  var _proto = PageProxy.prototype;

  _proto.getPagePath = function getPagePath(props) {
    var _ref = props || this.props,
        url = _ref.match.url;

    return url.substr(1) || 'home';
  };

  _proto.componentDidMount = function componentDidMount() {
    this.loadAsyncPages(this.getPagePath(this.props));
  };

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var currentPath = this.getPagePath(this.props);
    var nextPath = this.getPagePath(nextProps);

    if (currentPath !== nextPath) {
      this.loadAsyncPages(nextPath);
    }
  };

  PageProxy.getDerivedStateFromError = function getDerivedStateFromError(error) {
    return {
      hasError: true,
      error: error
    };
  };

  _proto.componentDidCatch = function componentDidCatch(err, info) {
    this.warn('哎呀，出错了');
    this.warn(info.componentStack);
  };

  _proto.renderPageElement = function renderPageElement(props, Loading) {
    var state = this.state;
    var Page = state[this.getPagePath(this.props)];

    if (Page) {
      var useLayout = Page.useLayout;
      this.useLayout = typeof useLayout === 'boolean' ? useLayout : true; //缓存当前useLayout的状态，进入下一个页面的时候避免发生layout的切换导致的闪动

      return [React.createElement(Page, this.props), this.useLayout];
    } //读取之前的layout状态，如果不存在就用true


    var ul = this.useLayout === 'boolean' ? this.useLayout : true;
    return [Loading ? React.createElement(Loading, null) : React.createElement("div", null, "\u52A0\u8F7D\u4E2D..."), ul];
  };

  _proto.render = function render() {
    var _this$props = this.props,
        ErrorComp = _this$props.ErrorComp,
        Layout = _this$props.Layout,
        LoadingComp = _this$props.LoadingComp,
        props = _objectWithoutPropertiesLoose(_this$props, ["ErrorComp", "Layout", "LoadingComp"]);

    if (this.state.hasError && ErrorComp) return React.createElement(ErrorComp, _extends({
      error: this.state.error
    }, props));

    var _this$renderPageEleme = this.renderPageElement(props, LoadingComp),
        pageElement = _this$renderPageEleme[0],
        useLayout = _this$renderPageEleme[1];

    if (!useLayout || !Layout) return pageElement;
    return React.createElement(Layout, this.props, pageElement);
  };

  _proto.warn = function warn(msg, err) {
    if (console && console.error) {
      console.error(msg);
      if (err) throw err;
    }
  };

  _proto.loadAsyncPages = function loadAsyncPages(path) {
    var _this2 = this;

    var loadPage = this.state[path] ? undefined : import(
    /* webpackMode: "lazy", webpackChunkName: "[request]" */
    "_/src/pages/" + path + "/page-view");
    Promise.all([loadPage]).then(function (_ref2) {
      var PageComponent = _ref2[0];
      var needUpdate = false;
      var updateData = {};

      if (PageComponent) {
        needUpdate = true;
        updateData[path] = PageComponent[df];
      }

      if (_this2.state[currentPage] !== path) {
        needUpdate = true;
        updateData[currentPage] = path;
      }

      if (needUpdate) {
        _this2.setState(updateData);
      }
    }).catch(function (err) {
      _this2.warn("\u9875\u9762 " + path + " \u52A0\u8F7D\u5931\u8D25", err);
    });
  };

  return PageProxy;
}(Component);

export { PageProxy as default };
